.def("qryOrderProcess", &TdApi::qryOrderProcess)
.def("qryDeepQuote", &TdApi::qryDeepQuote)
.def("qryAccountRent", &TdApi::qryAccountRent)
.def("qryAccountFeeRent", &TdApi::qryAccountFeeRent)
.def("qryAccountMarginRent", &TdApi::qryAccountMarginRent)
.def("qryAccountCashAdjust", &TdApi::qryAccountCashAdjust)
.def("qryBill", &TdApi::qryBill)
.def("qryHisOrder", &TdApi::qryHisOrder)
.def("qryHisOrderProcess", &TdApi::qryHisOrderProcess)
.def("qryHisFill", &TdApi::qryHisFill)
.def("qryHisPosition", &TdApi::qryHisPosition)
.def("qryHisDelivery", &TdApi::qryHisDelivery)
.def("qryManageInfoForEStar", &TdApi::qryManageInfoForEStar)
.def("qrySystemParameter", &TdApi::qrySystemParameter)
.def("qryTradeCenterFrontAddress", &TdApi::qryTradeCenterFrontAddress)
.def("qryTradeMessage", &TdApi::qryTradeMessage)
.def("qryAccountStorage", &TdApi::qryAccountStorage)
.def("qrySpotLock", &TdApi::qrySpotLock)
.def("qryTrustDevice", &TdApi::qryTrustDevice)
.def("qryManagerConfigFile", &TdApi::qryManagerConfigFile)

.def("onConnect", &TdApi::onConnect)
.def("onRspLogin", &TdApi::onRspLogin)
.def("onRtnContactInfo", &TdApi::onRtnContactInfo)
.def("onRspRequestVertificateCode", &TdApi::onRspRequestVertificateCode)
.def("onRspRequestVerifyIdentity", &TdApi::onRspRequestVerifyIdentity)
.def("onRspSetVertificateCode", &TdApi::onRspSetVertificateCode)
.def("onRtnErrorMsg", &TdApi::onRtnErrorMsg)
.def("onAPIReady", &TdApi::onAPIReady)
.def("onDisconnect", &TdApi::onDisconnect)
.def("onRspSubmitUserLoginInfo", &TdApi::onRspSubmitUserLoginInfo)
.def("onRspChangePassword", &TdApi::onRspChangePassword)
.def("onRspSetReservedInfo", &TdApi::onRspSetReservedInfo)
.def("onRtnContract", &TdApi::onRtnContract)
.def("onRtnFund", &TdApi::onRtnFund)
.def("onRtnOrder", &TdApi::onRtnOrder)
.def("onRspOrderAction", &TdApi::onRspOrderAction)
.def("onRspQryOrderProcess", &TdApi::onRspQryOrderProcess)
.def("onRtnFill", &TdApi::onRtnFill)
.def("onRtnPosition", &TdApi::onRtnPosition)
.def("onRtnClose", &TdApi::onRtnClose)
.def("onRtnPositionProfit", &TdApi::onRtnPositionProfit)
.def("onRspQryDeepQuote", &TdApi::onRspQryDeepQuote)
.def("onRtnExchangeStateInfo", &TdApi::onRtnExchangeStateInfo)
.def("onRtnReqQuoteNotice", &TdApi::onRtnReqQuoteNotice)
.def("onRspAccountRentInfo", &TdApi::onRspAccountRentInfo)
.def("onRspTradeMessage", &TdApi::onRspTradeMessage)
.def("onRtnTradeMessage", &TdApi::onRtnTradeMessage)
.def("onRspQryHisOrder", &TdApi::onRspQryHisOrder)
.def("onRspQryHisOrderProcess", &TdApi::onRspQryHisOrderProcess)
.def("onRspQryHisFill", &TdApi::onRspQryHisFill)
.def("onRspQryHisPosition", &TdApi::onRspQryHisPosition)
.def("onRspQryHisDelivery", &TdApi::onRspQryHisDelivery)
.def("onRspQryAccountCashAdjust", &TdApi::onRspQryAccountCashAdjust)
.def("onRspQryBill", &TdApi::onRspQryBill)
.def("onRspAccountFeeRent", &TdApi::onRspAccountFeeRent)
.def("onRspAccountMarginRent", &TdApi::onRspAccountMarginRent)
.def("onRspAddMobileDevice", &TdApi::onRspAddMobileDevice)
.def("onRspQryManageInfoForEStar", &TdApi::onRspQryManageInfoForEStar)
.def("onRspQrySystemParameter", &TdApi::onRspQrySystemParameter)
.def("onRspQryTradeCenterFrontAddress", &TdApi::onRspQryTradeCenterFrontAddress)
.def("onRtnCommodityInfo", &TdApi::onRtnCommodityInfo)
.def("onRtnCurrencyInfo", &TdApi::onRtnCurrencyInfo)
.def("onRspQryAccountStorage", &TdApi::onRspQryAccountStorage)
.def("onRtnAccountStorage", &TdApi::onRtnAccountStorage)
.def("onRspQrySpotLock", &TdApi::onRspQrySpotLock)
.def("onRtnSpotLock", &TdApi::onRtnSpotLock)
.def("onRspSpecialOrderAction", &TdApi::onRspSpecialOrderAction)
.def("onRtnSpecialOrder", &TdApi::onRtnSpecialOrder)
.def("onRtnCombinePosition", &TdApi::onRtnCombinePosition)
.def("onRtnContractQuote", &TdApi::onRtnContractQuote)
.def("onRspQryTrustDevice", &TdApi::onRspQryTrustDevice)
.def("onRspAddTrustDevice", &TdApi::onRspAddTrustDevice)
.def("onRspDelTrustDevice", &TdApi::onRspDelTrustDevice)
.def("onRtnAddUserRight", &TdApi::onRtnAddUserRight)
.def("onRtnDelUserRight", &TdApi::onRtnDelUserRight)
.def("onRspQryManagerConfigFile", &TdApi::onRspQryManagerConfigFile)
;
