#define ONCONNECT 0
#define ONRSPLOGIN 1
#define ONRTNCONTACTINFO 2
#define ONRSPREQUESTVERTIFICATECODE 3
#define ONRSPREQUESTVERIFYIDENTITY 4
#define ONRSPSETVERTIFICATECODE 5
#define ONRTNERRORMSG 6
#define ONAPIREADY 7
#define ONDISCONNECT 8
#define ONRSPSUBMITUSERLOGININFO 9
#define ONRSPCHANGEPASSWORD 10
#define ONRSPSETRESERVEDINFO 11
#define ONRTNCONTRACT 12
#define ONRTNFUND 13
#define ONRTNORDER 14
#define ONRSPORDERACTION 15
#define ONRSPQRYORDERPROCESS 16
#define ONRTNFILL 17
#define ONRTNPOSITION 18
#define ONRTNCLOSE 19
#define ONRTNPOSITIONPROFIT 20
#define ONRSPQRYDEEPQUOTE 21
#define ONRTNEXCHANGESTATEINFO 22
#define ONRTNREQQUOTENOTICE 23
#define ONRSPACCOUNTRENTINFO 24
#define ONRSPTRADEMESSAGE 25
#define ONRTNTRADEMESSAGE 26
#define ONRSPQRYHISORDER 27
#define ONRSPQRYHISORDERPROCESS 28
#define ONRSPQRYHISFILL 29
#define ONRSPQRYHISPOSITION 30
#define ONRSPQRYHISDELIVERY 31
#define ONRSPQRYACCOUNTCASHADJUST 32
#define ONRSPQRYBILL 33
#define ONRSPACCOUNTFEERENT 34
#define ONRSPACCOUNTMARGINRENT 35
#define ONRSPADDMOBILEDEVICE 36
#define ONRSPQRYMANAGEINFOFORESTAR 37
#define ONRSPQRYSYSTEMPARAMETER 38
#define ONRSPQRYTRADECENTERFRONTADDRESS 39
#define ONRTNCOMMODITYINFO 40
#define ONRTNCURRENCYINFO 41
#define ONRSPQRYACCOUNTSTORAGE 42
#define ONRTNACCOUNTSTORAGE 43
#define ONRSPQRYSPOTLOCK 44
#define ONRTNSPOTLOCK 45
#define ONRSPSPECIALORDERACTION 46
#define ONRTNSPECIALORDER 47
#define ONRTNCOMBINEPOSITION 48
#define ONRTNCONTRACTQUOTE 49
#define ONRSPQRYTRUSTDEVICE 50
#define ONRSPADDTRUSTDEVICE 51
#define ONRSPDELTRUSTDEVICE 52
#define ONRTNADDUSERRIGHT 53
#define ONRTNDELUSERRIGHT 54
#define ONRSPQRYMANAGERCONFIGFILE 55
