int qryOrderProcess(const dict &data, unsigned int session, const dict &data);

int qryDeepQuote(const dict &data, unsigned int session, const dict &data);

int qryAccountRent(const dict &data, unsigned int session, const dict &data);

int qryAccountFeeRent(const dict &data, unsigned int session, const dict &data);

int qryAccountMarginRent(const dict &data, unsigned int session, const dict &data);

int qryAccountCashAdjust(const dict &data, unsigned int session, const dict &data);

int qryBill(const dict &data, unsigned int session, const dict &data);

int qryHisOrder(const dict &data, unsigned int session, const dict &data);

int qryHisOrderProcess(const dict &data, unsigned int session, const dict &data);

int qryHisFill(const dict &data, unsigned int session, const dict &data);

int qryHisPosition(const dict &data, unsigned int session, const dict &data);

int qryHisDelivery(const dict &data, unsigned int session, const dict &data);

int qryManageInfoForEStar(const dict &data, unsigned int session, const dict &data);

int qrySystemParameter(const dict &data, unsigned int session, const dict &data);

int qryTradeCenterFrontAddress(const dict &data, unsigned int session, const dict &data);

int qryTradeMessage(const dict &data, unsigned int session, const dict &data);

int qryAccountStorage(const dict &data, unsigned int session, const dict &data);

int qrySpotLock(const dict &data, unsigned int session, const dict &data);

int qryTrustDevice(const dict &data, unsigned int session, const dict &data);

int qryManagerConfigFile(const dict &data, unsigned int session, const dict &data);

